-- Decimal Time Hands

-- 1 day = 10 hours
-- 1 hour = 100 minutes
-- 1 minute = 100 seconds
-- 1 second = 1/100000th of a day

-- also revolutionary french system
-- hours and minutes also correspond to swatch time .beats, seconds are "centi.beats"

local hands = {}

hands.dots = {}
for i=1,100 do
	local d = {
		angle = (((math.pi * 2) / 100) * i) - (math.pi / 2)
	}
	d.o = 27
	d.i = 20.75
	d.x = ((radius / 27) * 20.75) * math.cos(d.angle) + (screen.width / 2)
	d.y = ((radius / 27) * 20.75) * math.sin(d.angle) + (screen.height / 2)
	d.reach = (i % 10 == 0) and 0.02 or 0.01
	d.radius = (i % 10 == 0) and radius * 0.02 or radius * 0.01
	d.color = {127,127,127}
	hands.dots[#hands.dots + 1] = d
end

hands.dots.drawinfo = function(self,t)

	local dh = tostring(math.floor(t/8640)%10)
	local dm = tostring(math.floor(t / 86.4) % 100)
	local ds = tostring(math.floor(t / 0.864) % 100)
	local du = tostring((math.floor(t / 0.0864) % 100))

	if dm:len() < 2 then dm = '0' .. dm end
	if ds:len() < 2 then ds = '0' .. ds end
	if du:len() < 2 then du = '0' .. du end

	-- decimal time
	love.graphics.print(
		dh .. '_' .. dm .. '.' .. ds .. ',' .. du,
		screen.width / 2 - love.graphics.getFont():getWidth(dh .. '_' .. dm .. '.' .. ds .. ',' .. du) / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 20 * (radius / 1000)
	)

	-- swatch .beat time
	love.graphics.print(
		'@' .. dh .. dm .. '.' .. math.floor(ds/10) .. '.' .. (ds%10),
		screen.width / 2 - love.graphics.getFont():getWidth('@' .. dh .. dm .. '.' .. math.floor(ds/10) .. '.' .. (ds%10)) / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 27.5 * (radius / 1000)
	)

	-- elapsed day percentage
	s1 = tostring(math.floor((accum/86400)*100)%100)
	s2 = tostring(math.floor((accum/86400)*100000)%1000)
	if s2:len() < 3 then s2 = '0' .. s2 end
	if s2:len() < 3 then s2 = '0' .. s2 end
	s = s1 .. '.' .. s2 .. '%'
	love.graphics.print(
		s,
		screen.width / 2 - love.graphics.getFont():getWidth(s) / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 35 * (radius / 1000)
	)
end

-- sub-seconds
hands[1] = {
	color = {64, 4, 16},
	reach = 6/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = ((math.pi * 2) / 100) * (dt / 0.0864)
		           - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- seconds
hands[2] = {
	color = {128,32,0},
	reach = 12/16,
	angle = 0,
	x = 0,
	y = 0,
	-- seconds, though lose the modulo, and it would update constantly
	update = function(self,dt)
		self.angle = ((math.pi * 2) / 100) * (math.floor((dt / 0.864) % 100))
		           - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- minutes
hands[3] = {
	color = {128,16,16},
	reach = 10.5/16,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = ((math.pi * 2) / 100) * (math.floor(dt / 86.4))
		           - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- hours
hands[4] = {
	color = {96,0,16},
	reach = 3/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = (( math.pi * 2) / 10)       * (math.floor(dt / 8640)     )
				   - (  math.pi / 2)
				   --+ (((math.pi * 2) / 12) / 60) * (math.floor(dt /   60) % 60)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(2)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

return hands