-- NET (New Earth Time) Hands

-- 1 day = 360 degrees
-- 1 degree = 60 minutes
-- 1 minute = 60 seconds
-- 1 second = 1/1296000th of a day

-- 15 degrees every STD hour
-- 4 minutes per degree

local hands = {}

hands.dots = {}
for i=1,360 do
	local d = {
		angle = (((math.pi * 2) / 360) * i) - (math.pi / 2)
	}
	d.o = 360
	d.i = 350
	d.x = ((radius / 360) * 350) * math.cos(d.angle) + (screen.width / 2)
	d.y = ((radius / 360) * 350) * math.sin(d.angle) + (screen.height / 2)
	d.reach = 0.001
	d.radius = radius * 0.001
	if i % 6 == 0 then
		d.reach = 0.005
		d.radius = radius * 0.005
	end
	if i % 15 == 0 then
		d.reach = 0.02
		d.radius = radius * 0.02
	end
	d.color = {127,127,127}
	hands.dots[#hands.dots + 1] = d
end

hands.dots.drawinfo = function(self,t)

	local deg = tostring(math.floor(t / 240)%360)
	local arcmin = tostring(math.floor(t / 60) % 60)
	local arcsec = tostring(math.floor(t % 60))
	local u = tostring((math.floor(t * 24) % 24) * 15)

	if deg:len() < 2 then deg = ' ' .. deg end
	if deg:len() < 2 then deg = ' ' .. deg end
	if arcmin:len() < 2 then arcmin = ' ' .. arcmin end
	if arcsec:len() < 2 then arcsec = ' ' .. arcsec end
	if u:len() < 3 then u = '0' .. u end
	if u:len() < 3 then u = '0' .. u end

	love.graphics.print(
		deg .. '° ' .. arcmin .. '" ' .. arcsec .. '\' ' .. u,
		screen.width / 2 - love.graphics.getFont():getWidth(deg .. '° ' .. arcmin .. '" ' .. arcsec .. '\' ' .. u) / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 20 * (radius / 1000)
	)
	love.graphics.print(
		math.floor(math.rad(deg)*100)/100 .. ' rad (' .. math.floor((math.rad(deg)/math.pi)*100)/100 .. ' pi)',
		screen.width / 2 - love.graphics.getFont():getWidth(math.floor(math.rad(deg)*100)/100 .. ' rad (' .. math.floor((math.rad(deg)/math.pi)*100)/100 .. ' pi)') / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 27.5 * (radius / 1000)
	)

end

-- sub-seconds
hands[1] = {
	color = {0, 32, 0},
	reach = 19/20,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = ((math.pi * 2) /  24) * (math.floor(dt * 24) % 24)
		           - ( math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- seconds
hands[2] = {
	color = {0,64,4},
	reach = 39/40,
	angle = 0,
	x = 0,
	y = 0,
	-- seconds, though lose the modulo, and it would update constantly
	update = function(self,dt)
		self.angle = ((math.pi * 2) / 60) * (math.floor(dt % 60))
		           - ( math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- minutes
hands[3] = {
	color = {16,128,8},
	reach = 6.3/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = (( math.pi * 2) / 60)       * (math.floor(dt / 60))
		           - (  math.pi / 2)
		           + (((math.pi * 2) / 60) / 4) * (math.floor(dt/15)%4)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- degrees
hands[4] = {
	color = {48,192,16},
	reach = 3.6/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = (( math.pi * 2) / 360)       * (math.floor(dt / 240)     )
				   - (  math.pi / 2)
				   + (((math.pi * 2) / 360) / 60) * (math.floor(dt /   60) % 60)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(2)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

return hands