-- Hexadecimal time (also base2, base8 and base64)

-- 1 day = 2x12 hours
-- 1 hour = 60 minutes
-- 1 minute = 60 seconds
-- 1 second = 1/86400th of a day

local hands = {}

hands.dots = {}
for i=1,64 do
	local d = {
		angle = (((math.pi * 2) / 64) * i) - (math.pi / 2)
	}
	d.o = 12
	d.i = 6.75
	d.x = ((radius / 12) * 6.75) * math.cos(d.angle) + (screen.width / 2)
	d.y = ((radius / 12) * 6.75) * math.sin(d.angle) + (screen.height / 2)
	d.reach = (i % 8 == 0) and 0.015 or ((i % 4 == 0) and 0.008 or 0.00375)
	d.radius = (i % 8 == 0) and radius * 0.015 or ((i % 4 == 0) and radius * 0.008 or radius * 0.00375)
	d.color = {127,127,127}
	hands.dots[#hands.dots + 1] = d
end

hands.dots.drawinfo = function(self,t)

	local b16T = {
		'0','1','2','3','4','5','6','7','8','9','A','B','C','D','E','F'
	}

	local b64T = {
		'A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P',
		'Q','R','S','T','U','V','W','X','Y','Z','a','b','c','d','e','f',
		'g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v',
		'w','x','y','z','0','1','2','3','4','5','6','7','8','9','+','/'
	}

	local Bh = math.floor(t / 1350) % 64
	local Bm = math.floor(t / 21.09375) % 64
	local Bs = math.floor(t / 0.32958984375) % 64

	local xh = math.floor(t / 5400) % 16
	local xm = math.floor(t / 337.5) % 16
	local xs = math.floor(t / 21.09375) % 16
	local xu = math.floor(t / 1.318359375) % 16

	-- base 16 (and 64)
	love.graphics.print(
		'0x' .. b16T[xh+1]  .. b16T[xm+1]  .. b16T[xs+1] .. b16T[xu+1] .. ' (' .. b64T[Bh+1] .. b64T[Bm+1] .. b64T[Bs+1] .. ')',
		screen.width / 2 - love.graphics.getFont():getWidth('0x' .. b16T[xh+1]  .. b16T[xm+1]  .. b16T[xs+1] .. b16T[xu+1] .. ' (' .. b64T[Bh+1] .. b64T[Bm+1] .. b64T[Bs+1] .. ')') / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 20 * (radius / 1000)
	)

	local oh = math.floor(t / 10800) % 8
	local om = math.floor(t / 1350) % 8
	local os = math.floor(t / 168.75) % 8
	local ou = math.floor(t / 21.09375) % 8
	local ov = math.floor(t / 2.63671875) % 8

	-- base 8
	love.graphics.print(
		'0' .. oh .. om .. os .. ou .. ov,
		screen.width / 2 - love.graphics.getFont():getWidth('0' .. oh .. om .. os .. ou .. ov) / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 27.5 * (radius / 1000)
	)

	-- base 2
	local b2 = ''
	for i=1,20 do
		b2 = b2 .. math.floor((t / 86400) * 2^i) % 2
	end
	love.graphics.print(
		b2,
		screen.width / 2 - love.graphics.getFont():getWidth(b2) / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 35 * (radius / 1000)
	)

end

-- sub-seconds
hands[1] = {
	color = {32, 32, 32},
	reach = 4.5/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = ((math.pi * 2) /  16) * ((dt / 1.318359375) % 16)
		           - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1.25)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- seconds
hands[2] = {
	color = {64,64,64},
	reach = 4.25/8,
	angle = 0,
	x = 0,
	y = 0,
	-- seconds, though lose the modulo, and it would update constantly
	update = function(self,dt)
		self.angle = ((math.pi * 2) / 16) * (math.floor(dt / 21.09375) % 16)
		           - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1.5)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- minutes
hands[3] = {
	color = {128,128,128},
	reach = 3.5/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = ((math.pi * 2) / 16) * (math.floor(dt / 337.5) % 16)
		           - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1.5)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- hours
hands[4] = {
	color = {192,192,192},
	reach = 2.67/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = (( math.pi * 2) / 16)       * (math.floor(dt / 5400) % 16)
				   - (  math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(3)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

return hands