-- Standard Time Hands

-- 1 day = 2x12 hours
-- 1 hour = 60 minutes
-- 1 minute = 60 seconds
-- 1 second = 1/86400th of a day

local hands = {}

hands.dots = {}
for i=1,60 do
	local d = {
		angle = (((math.pi * 2) / 60) * i) - (math.pi / 2)
	}
	d.o = 12
	d.i = 10.5
	d.x = ((radius / 12) * 10.5) * math.cos(d.angle) + (screen.width / 2)
	d.y = ((radius / 12) * 10.5) * math.sin(d.angle) + (screen.height / 2)
	d.reach = (i % 5 == 0) and 0.03 or 0.01
	d.radius = (i % 5 == 0) and radius * 0.03 or radius * 0.01
	d.color = {127,127,127}
	hands.dots[#hands.dots + 1] = d
end

hands.dots.drawinfo = function(self,t)

	local meridian	--os.date('%p'):lower()
	if t >= 0 and t < 0+3600 then
		meridian = ' n'
	elseif t > 0 and t < 43200 then
		meridian = 'am'
	elseif t >= 43200 and t < 43200+3600 then
		meridian = ' m'
	else--if t > 43200 and t < 86400 then
		meridian = 'pm'
	end

	local x = tostring(math.floor((t / 3600 ) % 12))										--tostring(tonumber(os.date('%I')))
	x = (x == '0') and '12' or x

	local h = tostring(math.floor(t / 3600)%24)																	--os.date('%H')
	local m = tostring(math.floor(t / 60) % 60)
	local s = tostring(math.floor(t % 60))
	local u = tostring(math.floor((t*10 % 10)))
	--if x:len() ~= 2 then x = ' ' .. x end
	if h:len() ~= 2 then h = 0 .. h end
	if m:len() ~= 2 then m = 0 .. m end
	if s:len() ~= 2 then s = 0 .. s end
	love.graphics.print(
		h .. ':' .. m .. ':' .. s .. '.' .. u,
		screen.width / 2 - love.graphics.getFont():getWidth(h .. ':' .. m .. ':' .. s .. '.' .. u) / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 20 * (radius / 1000)
	)
	love.graphics.print(
		'(' .. x .. ' ' .. meridian .. ')' ,
		screen.width / 2 - love.graphics.getFont():getWidth('(' .. x .. ' ' .. meridian .. ')') / 2, 
		screen.height / 2 + love.graphics.getFont():getHeight() * 27.5 * (radius / 1000)
	)
end

-- sub-seconds
hands[1] = {
	color = {0, 16, 32},
	reach = 17/19,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		--self.angle = ((math.pi * 2) /  4) * (math.floor(dt * 4) % 4) - (math.pi / 2)
		self.angle = ((math.pi * 2) /  1) * (           dt) - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- seconds
hands[2] = {
	color = {128,32,0},
	reach = 7/8,
	angle = 0,
	x = 0,
	y = 0,
	-- seconds, though lose the modulo, and it would update constantly
	update = function(self,dt)
		self.angle = ((math.pi * 2) / 60) * (math.floor(dt % 60)) - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- minutes
hands[3] = {
	color = {0,64,128},
	reach = 6.5/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = ((math.pi * 2) / 60) * (dt / 60) - (math.pi / 2)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(1)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

-- hours
hands[4] = {
	color = {0,128,255},
	reach = 4.5/8,
	angle = 0,
	x = 0,
	y = 0,
	update = function(self,dt)
		self.angle = (( math.pi * 2) / 12)       * (math.floor(dt / 3600)     )
				   - (  math.pi / 2)
				   + (((math.pi * 2) / 12) / 60) * (math.floor(dt /   60) % 60)
		self.x, self.y = calcCoords(self)
	end,
	draw = function(self)
		love.graphics.setColor(self.color)
		love.graphics.setLineWidth(2)
		love.graphics.line(screen.width / 2, screen.height / 2, self.x, self.y)
	end,
}

return hands